rm(list=ls())

library(nlme)
library(car)
library(MuMIn)
library(ggplot2)
library(effects)
library(ape)
library(lattice)
library(yhat)
library(lsmeans)
library(multcompView)

## Dataset

CT <-read.csv("CTmax_data.csv", h=T)
names(CT)
head(CT)    
summary(CT)
str(CT)
dim(CT)

#new variables
CT$trial <- as.factor(CT$trial); is.factor(CT$trial)
CT$spTrial <- paste(CT$species, CT$trial, sep = "_")
CT$spTreat <- paste(CT$species, CT$treatment, sep = "_")
CT$spTreatTrial <- paste(CT$species, CT$treatment, CT$trial, sep = "_")

#subsets
control <- CT[CT$treatment=="Control" , ]; control <- droplevels(control); summary(control)
CO2 <- CT[CT$treatment=="CO2" , ]; CO2 <- droplevels(CO2); summary(CO2)

#######
# graphs of raw data (outliers included)
#######

# CTmax by mass * species 
xyplot(CTmax ~  mass|species, type=c("p", "smooth"), data=CT)
xyplot(CTmax ~  log(mass)|species, type=c("p", "smooth"), data=CT)
xyplot(CTmax ~  sqrt(mass)|species, type=c("p", "smooth"), data=CT)

# CTmax by mass * species for control fish (2-way interaction)
ggplot(control, aes(mass, CTmax)) + geom_point(aes(colour = factor(species)), size = 3) + 
	facet_wrap(~ species) + geom_smooth(method = "lm", se = FALSE) +
	theme(axis.text=element_text(size=10), axis.title=element_text(size=12)) + 
	theme_bw()

# CTmax by mass * species for CO2 fish (2-way interaction)
ggplot(CT, aes(mass, CTmax)) + geom_point(aes(colour = factor(species)), size = 3) + 
	facet_wrap(~ trial) + geom_smooth(method = "lm", se = FALSE) +
	theme(axis.text=element_text(size=10), axis.title=element_text(size=12)) + 
	theme_bw()

# CTmax by mass * trial (2-way interaction)
ggplot(CO2, aes(mass, CTmax)) + geom_point(aes(colour = factor(species)), size = 3) + 
	facet_wrap(~ species) + geom_smooth(method = "lm", se = FALSE) +
	theme(axis.text=element_text(size=10), axis.title=element_text(size=12)) + 
	theme_bw()

# CTmax by species * treatment *trial (3-way interaction)
qplot(spTreatTrial, CTmax, data = CT, geom = "boxplot", colour = I("#3366FF"), outlier.size = 3) +
	geom_point(position = position_jitter(w = 0.1, h = 0.1), colour = I("black"), size = I(2), shape = 1) +
	theme(axis.text=element_text(size=10), axis.title=element_text(size=12)) + 
	theme_bw()

# CTmax by species * treatment (2-way interaction)
qplot(spTreat, CTmax, data = CT, geom = "boxplot", colour = I("#3366FF"), outlier.size = 2) +
	geom_point(position = position_jitter(w = 0.2, h = 0), colour = I("black"), size = I(2), shape = 1) +
	geom_text(aes(label=fishID), hjust=0, vjust=0) + theme(axis.text=element_text(size=10), 
	axis.title=element_text(size=12)) + 
	theme_bw()

# CTmax by species * trial (2-way interaction)
qplot(spTrial, CTmax, data = CT, geom = "boxplot", colour = I("#3366FF"), outlier.size = 3) +
	geom_point(position = position_jitter(w = 0.1, h = 0.1), colour = I("black"), size = I(2), shape = 1) +
	theme(axis.text=element_text(size=10), axis.title=element_text(size=12)) + 
	theme_bw()

# CTmax by species (main effect)
qplot(species, CTmax, data = CT, geom = "boxplot", colour = I("#3366FF"), outlier.size = 3) +
	geom_point(position = position_jitter(w = 0.1, h = 0.1), colour = I("black"), size = I(2), shape = 1) +
	theme(axis.text=element_text(size=10), axis.title=element_text(size=12)) + 
	theme_bw()

# CTmax by treatment (main effect)
qplot(treatment, CTmax, data = CT, geom = "boxplot", colour = I("#3366FF"), outlier.size = 3) +
	geom_point(position = position_jitter(w = 0.1, h = 0.1), colour = I("black"), size = I(2), shape = 1) +
	theme(axis.text=element_text(size=10), axis.title=element_text(size=12)) + 
	theme_bw()

#######
# Fixed-effects model
#######

CT$centeredmass <- CT$mass - mean(CT$mass)

f1 <- lm(CTmax ~ trial * centeredmass * species * treatment, data=CT)
	# diagnostics 
	residualPlots(f1)
	qqPlot(resid(f1), id.n=10)
outlierTest(f1)

f1b <- lm(CTmax ~ trial * centeredmass * species * treatment, data=CT[-c(38,49,194,30,195),])
	residualPlots(f1b)
	qqPlot(resid(f1b), id.n=10)

f2 <- lm(CTmax ~ (trial + centeredmass + species + treatment)^3, data=CT)
	# diagnostics 
	plot(f2)
	residualPlots(f2)
	qqPlot(resid(f2), id.n=10)
	outlierTest(f2)
anova(f1, f2)

f2b <- lm(CTmax ~ (trial + centeredmass + species + treatment)^3, data=CT[-c(38,49,194,30,195),])
	residualPlots(f2b) # ID=38 is outlier
	qqPlot(resid(f2b), id.n=10)
anova(f1b, f2b) # retain simpler model (f2b)

f3 <- lm(CTmax ~ (trial + centeredmass + species + treatment)^2, data=CT)
	# diagnostics 
	plot(f3)
	residualPlots(f3)
	qqPlot(f3, id.n=10)
	outlierTest(f3)
anova(f2, f3)
summary(f3)
anova(f3)
	# effect plots (plots of model predictions)
	plot(effect("species:treatment", f3), x.var="treatment")
	plot(effect("centeredmass:species", f3), x.var="centeredmass")
	plot(effect("trial", f3))	
	plot(effect("centeredmass", f3))
	plot(effect("species", f3))
	plot(effect("treatment", f3))

f3b <- lm(CTmax ~ (trial + centeredmass + species + treatment)^2, data=CT[-c(38,49,194,30,195),])
	# diagnostics 
	plot(f3b)
	qqPlot(f3b, id.n=10)
	residualPlots(f3b)
anova(f3b, f2b)
summary(f3b)
anova(f3b)
	# effect plots (plots of model predictions)
	plot(effect("species:treatment", f3b), x.var="treatment")
	plot(effect("centeredmass:species", f3b), x.var="centeredmass")
	plot(effect("trial:species", f3b), x.var="trial")
	plot(effect("trial:centeredmass", f3b), x.var="centeredmass")
	plot(effect("trial", f3b))	
	plot(effect("centeredmass", f3b))
	plot(effect("species", f3b))
	plot(effect("treatment", f3b))

lsmeans(f3b, "trial")
lsmeans(f3b, "species")
lsmeans(f3b, "treatment")
lsmeans(f3b, "trial", by = "species")
lsmeans(f3b, "treatment", by = "species")

#post-hoc comparisons

cld(lstrends (f3b, ~ species, var = "centeredmass") ) # average slopes for each species. Comparisons with zero (via CI's) and, in the last column, pairwise comparisons

lsm1 <- lsmeans(f3b, "treatment", by = "species")
contrast(lsm1, method = "pairwise")  # comparisons across trials, at a mean value of mass

lsm2 <- lsmeans(f3b, "trial", by = "species")
contrast(lsm2, method = "pairwise")  # comparisons across trials, at a mean value of mass

cld(lstrends (f3b, ~ trial, var = "centeredmass") ) # average slopes for each trial. Comparisons with zero (via CI's) and, in the last column, pairwise comparisons

contrast(lsmeans(f3b, "species"), method = "pairwise") 

contrast(lsmeans(f3b, "trial"), method = "pairwise") 


#------------------------------------------------------------------------------------------


#######
# Mixed-effects model
#######

m1 <- lme(CTmax ~ (mass + treatment + species)^3, random=~1|trial, data=CT)
	# diagnostics
	plot(m1)
	qqPlot(resid(m1), id.n=10, labels=NULL)
	qqnorm(m1, ~ ranef(., level=1))
	plot(m1, trial~resid(.))

anova(m1)

m1b <- lme(CTmax ~ (mass + treatment + species)^3, random=~1|trial, data=CT[-c(38,49,194,30,195),])
	# diagnostics
	plot(m1b)
	qqPlot(resid(m1b), id.n=10, labels=NULL)
	qqnorm(m1b, ~ ranef(., level=1))
	plot(m1b, trial~resid(.))
anova(m1b)


m2 <- lme(CTmax ~ (mass + treatment + species)^2, random=~1|trial, data=CT)
# diagnostics
	plot(m2)
	qqPlot(resid(m2), id.n=10)  
	qqnorm(m2, ~ ranef(., level=1))	
	plot(m2, trial~resid(.))
anova(m1, m2)
summary(m2)
anova(m2)

m2b <- lme(CTmax ~ (mass + treatment + species)^2, random=~1|trial, data=CT[-c(38,49,194,30,195),])
# diagnostics
	qqPlot(resid(m2b), labels=NULL)#id.n=10)
	plot(m2b)
  	qqnorm(m2b, ~ ranef(., level=1))	
	plot(m2b, trial~resid(.))
anova(m1b, m2b)
summary(m2b)
anova(m2b) #qualitatively same results as f3b
r.squaredGLMM(m2b)
varcomp(m2b)
# effect plots (plots of model predictions)
	plot(effect("treatment:species", m2b), x.var="treatment")
	plot(effect("mass:species", m2b), x.var="mass")	
	plot(effect("mass", m2b))
	plot(effect("species", m2b))
	plot(effect("treatment", m2b))


















